@@ -14,10 +14,15 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
   }
 
 ######
-  if (sum(is.na(gbp.object$weight)) == 1) {
+  if (sum(is.na(gbp.object$weight)) == 1 & sum(is.na(gbp.object$p)) == 1) {
     IS <- FALSE
-  } else {
+    SIR <- FALSE
+  } else if (sum(is.na(gbp.object$weight)) != 1 & sum(is.na(gbp.object$p)) == 1) {
     IS <- TRUE
+    SIR <- FALSE
+  } else {
+    IS <- FALSE
+    SIR <- TRUE
   }
 
   # if model=BRIMM	
@@ -39,7 +44,7 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
       }
   
       n <- gbp.object$se
-      r <- exp(-gbp.object$a.new)
+      r <- as.numeric(exp(-gbp.object$a.new))
       priormeanused <- p0
 
       # 2. generate p matrix
@@ -52,7 +57,7 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
       for (i in 1 : nsim) {
         tryCatch({
 ######
-          if(IS == 0) {
+          if (IS == 0 & SIR == 0) {
             out <- if (is.na(gbp.object$prior.mean) & identical(gbp.object$X, NA)) {
                      gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha)
                    } else if (is.na(gbp.object$prior.mean) & !identical(gbp.object$X, NA)) {
@@ -60,20 +65,46 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
                    } else if (!is.na(gbp.object$prior.mean)) {
                      gbp(sim.z[, i], n, mean.PriorDist = p0, model = "binomial", Alpha = gbp.object$Alpha)
                    }
+          } else if (IS != 0 & SIR == 0) {
+            if (gbp.object$ISBeta == 0){
+              out <- if (is.na(gbp.object$prior.mean) & identical(gbp.object$X, NA)) {
+                       gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                     } else if (is.na(gbp.object$prior.mean) & !identical(gbp.object$X, NA)) {
+                       gbp(sim.z[, i], n, X, model = "binomial", Alpha = gbp.object$Alpha,
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                     } else if (!is.na(gbp.object$prior.mean)) {
+                       gbp(sim.z[, i], n, mean.PriorDist = p0, model = "binomial", Alpha = gbp.object$Alpha, 
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                     }
+            } else {
+              out <- if (is.na(gbp.object$prior.mean) & identical(gbp.object$X, NA)) {
+                       gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                           save.result = FALSE, ISBetaApprox = TRUE)
+                     } else if (is.na(gbp.object$prior.mean) & !identical(gbp.object$X, NA)) {
+                       gbp(sim.z[, i], n, X, model = "binomial", Alpha = gbp.object$Alpha,
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                           save.result = FALSE, ISBetaApprox = TRUE)
+                     } else if (!is.na(gbp.object$prior.mean)) {
+                       gbp(sim.z[, i], n, mean.PriorDist = p0, model = "binomial", Alpha = gbp.object$Alpha, 
+                           n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                           save.result = FALSE, ISBetaApprox = TRUE)
+                     }
+            }
           } else {
             out <- if (is.na(gbp.object$prior.mean) & identical(gbp.object$X, NA)) {
                      gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
-                         n.IS = length(gbp.object$weight))
+                         n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                    } else if (is.na(gbp.object$prior.mean) & !identical(gbp.object$X, NA)) {
                      gbp(sim.z[, i], n, X, model = "binomial", Alpha = gbp.object$Alpha,
-                         n.IS = length(gbp.object$weight))
+                         n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                    } else if (!is.na(gbp.object$prior.mean)) {
                      gbp(sim.z[, i], n, mean.PriorDist = p0, model = "binomial", Alpha = gbp.object$Alpha, 
-                         n.IS = length(gbp.object$weight))
+                         n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                    }
           }
 
-
           a1 <- r * p0 + sim.z[, i]
           a0 <- r * (1 - p0) + n - sim.z[, i]
           low <- out$post.intv.low
@@ -93,7 +124,7 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
       # 1. initial values
       if (missing(A.or.r) & missing(reg.coef) & !missing(mean.PriorDist)) {
         p0 <- mean.PriorDist
-        r <- exp(-gbp.object$a.new)
+        r <- as.numeric(exp(-gbp.object$a.new))
       } else if (missing(A.or.r) & !missing(reg.coef) & missing(mean.PriorDist)) {
         if (!identical(gbp.object$prior.mean, NA)) {
           print("reg.coef cannot be designated because there is no covariate.")
@@ -106,7 +137,7 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
           betas <- as.vector(reg.coef)
         }
         p0 <- exp(temp.x %*% betas) / (1 + exp(temp.x %*% betas))
-        r <- exp(-gbp.object$a.new)
+        r <- as.numeric(exp(-gbp.object$a.new))
       } else if (!missing(A.or.r) & missing(reg.coef) & missing(mean.PriorDist)) {
         if (!identical(gbp.object$prior.mean, NA)) {
           p0 <- gbp.object$prior.mean
@@ -159,7 +190,7 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
       for (i in 1 : nsim) {
         tryCatch({
 ######
-          if(IS == 0) {
+          if (IS == 0 & SIR == 0) {
             out <- if (!missing(mean.PriorDist)) {
                      gbp(sim.z[, i], n, mean.PriorDist = mean.PriorDist, model = "binomial", 
                          Alpha = gbp.object$Alpha)
@@ -179,28 +210,92 @@ coverage <- function(gbp.object, A.or.r, reg.coef, mean.PriorDist, nsim = 100) {
                        gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha)
                      }
                    }
+          } else if (IS != 0 & SIR == 0) {
+            if (gbp.object$ISBeta == 0){
+              out <- if (!missing(mean.PriorDist)) {
+                       gbp(sim.z[, i], n, mean.PriorDist = mean.PriorDist, model = "binomial", 
+                           Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight),
+                           trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                     } else if (!missing(A.or.r) & missing(reg.coef)) { 
+                       if (!identical(gbp.object$prior.mean, NA)) {
+                         gbp(sim.z[, i], n, mean.PriorDist = gbp.object$prior.mean, model = "binomial", 
+                             Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight),
+                             trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
+                           gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
+                               n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                               save.result = FALSE)
+                       }
+                     } else if (!missing(reg.coef)) {
+                       if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       }
+                     }
+            } else {
+              out <- if (!missing(mean.PriorDist)) {
+                       gbp(sim.z[, i], n, mean.PriorDist = mean.PriorDist, model = "binomial", 
+                           Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight),
+                           trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                     } else if (!missing(A.or.r) & missing(reg.coef)) { 
+                       if (!identical(gbp.object$prior.mean, NA)) {
+                         gbp(sim.z[, i], n, mean.PriorDist = gbp.object$prior.mean, model = "binomial", 
+                             Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight),
+                             trial.scale = gbp.object$trial.scale, save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       }
+                     } else if (!missing(reg.coef)) {
+                       if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
+                         gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
+                             n.IS = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, 
+                             save.result = FALSE)
+                       }
+                     }
+            }
           } else {
             out <- if (!missing(mean.PriorDist)) {
                      gbp(sim.z[, i], n, mean.PriorDist = mean.PriorDist, model = "binomial", 
-                         Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight))
+                         Alpha = gbp.object$Alpha, n.SIR = length(gbp.object$weight),
+                         trial.scale = gbp.object$trial.scale, save.result = FALSE)
                    } else if (!missing(A.or.r) & missing(reg.coef)) { 
                      if (!identical(gbp.object$prior.mean, NA)) {
                        gbp(sim.z[, i], n, mean.PriorDist = gbp.object$prior.mean, model = "binomial", 
-                           Alpha = gbp.object$Alpha, n.IS = length(gbp.object$weight))
+                           Alpha = gbp.object$Alpha, n.SIR = length(gbp.object$weight),
+                           trial.scale = gbp.object$trial.scale, save.result = FALSE)
                      } else if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
                        gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
-                           n.IS = length(gbp.object$weight))
+                           n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                      } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
                        gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
-                           n.IS = length(gbp.object$weight))
+                           n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                      }
                    } else if (!missing(reg.coef)) {
                      if (identical(gbp.object$prior.mean, NA) & identical(gbp.object$X, NA)){
                        gbp(sim.z[, i], n, model = "binomial", Alpha = gbp.object$Alpha,
-                           n.IS = length(gbp.object$weight))
+                           n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                      } else if (identical(gbp.object$prior.mean, NA) & !identical(gbp.object$X, NA)){
                        gbp(sim.z[, i], n, gbp.object$X, model = "binomial", Alpha = gbp.object$Alpha,
-                           n.IS = length(gbp.object$weight))
+                           n.SIR = length(gbp.object$weight), trial.scale = gbp.object$trial.scale, save.result = FALSE)
                      }
                    }
           }
